@@ -11,9 +11,16 @@
 class Stiff{
   private:
   public:
-
+	//! A definition of operator () taking three arguments.
+    /*!
+     * Evaluates the stiffness operator (i,j) of the current planar finite element.
+     * \param currentfe_ is an object of class FiniteElement<Integrator, ORDER,2,2>, current planar finite element
+     * \param i is an unsigned int, current finite element local index
+     * \param j is an unsigned int, current finite element local index
+     * returns a double.
+     */
 	template<class Integrator, UInt ORDER>
-	inline Real operator() (FiniteElement<Integrator, ORDER>& currentfe_, UInt i, UInt j, UInt iq, UInt ic = 0)
+	inline Real operator() (FiniteElement<Integrator, ORDER,2,2>& currentfe_, UInt i, UInt j, UInt iq, UInt ic = 0)
 	{
 	   	Real s = 0;
 	   	for (UInt icoor=0; icoor < 2; icoor ++)
@@ -23,6 +30,57 @@ class Stiff{
 	   	}
 	   	return s;
 	}
+	
+	//! A definition of operator () taking three arguments.
+    /*!
+     * Evaluates the stiffness operator (i,j) of the current superficial finite element.
+     * \param currentfe_ is an object of class FiniteElement<Integrator, ORDER,2,3>, current finite element
+     * \param i is an unsigned int, current finite element local index
+     * \param j is an unsigned int, current finite element local index
+     * returns a double.
+     */
+	
+	template<class Integrator, UInt ORDER>
+	inline Real operator() (FiniteElement<Integrator, ORDER,2,3>& currentfe_, UInt i, UInt j, UInt iq, UInt ic = 0)
+	{
+		Real s = 0;
+		
+		Eigen::Matrix<Real,2,1> grad_phi_i;
+		Eigen::Matrix<Real,2,1> grad_phi_j;
+		
+		grad_phi_i(0) = currentfe_.phiDerMaster(i, 0, iq);
+		grad_phi_i(1) = currentfe_.phiDerMaster(i, 1, iq);
+		grad_phi_j(0) = currentfe_.phiDerMaster(j, 0, iq);
+		grad_phi_j(1) = currentfe_.phiDerMaster(j, 1, iq);
+		
+		s = grad_phi_i.dot(currentfe_.metric()*grad_phi_j);
+		
+	   	return s;
+	}
+	
+	
+	//! A definition of operator () taking three arguments.
+    /*!
+     * Evaluates the stiffness operator (i,j) of the current superficial finite element.
+     * \param currentfe_ is an object of class FiniteElement<Integrator, ORDER,3,3>, current finite element
+     * \param i is an unsigned int, current finite element local index
+     * \param j is an unsigned int, current finite element local index
+     * returns a double.
+     */
+	
+	template<class Integrator, UInt ORDER>
+	inline Real operator() (FiniteElement<Integrator, ORDER,3,3>& currentfe_, UInt i, UInt j, UInt iq, UInt ic = 0)
+	{
+	   	Real s = 0;
+	   	for (UInt icoor=0; icoor < 3; icoor ++)
+	   	{
+	   		s += currentfe_.invTrJPhiDerMaster(i, icoor, iq)*currentfe_.invTrJPhiDerMaster(j, icoor, iq);
+
+	   	}
+	   	return s;
+	}
+	
+	
 };
 
 template <class Type>
@@ -30,30 +88,14 @@ class StiffAnys{
 };
 
 template <>
-class StiffAnys<Eigen::Matrix<Real,2,2> >{
+class StiffAnys<Eigen::Matrix<Real,2,2>>{
   private:
-    //! A reference to FiniteElement<Integrator>
-    /*!
-     * Stores a reference to the finite element where the stiffness operator is evaluated.
-     */
-    //FiniteElement<Integrator, ORDER>& currentfe_;
+
 	const Eigen::Matrix<Real,2,2>& K_;
   public:
 	//! A constructor.
-	/*!
-	 \param fe is a reference to FiniteElement<Integrator>
-	 */
-    //Stiff(FiniteElement<Integrator, ORDER>& fe):currentfe_(fe),K_(MatrixXr::Identity(2,2)){};
-    //Stiff():K_(MatrixXr::Identity(2,2)){};
-    //Stiff(Stiff<Integrator, ORDER>& stiff, Eigen::Matrix<Real,2,2> K): currentfe_(stiff.currentfe_) , K_(K){};
+    
     StiffAnys(const Eigen::Matrix<Real,2,2>& K): K_(K){};
-    //! A definition of operator () taking two arguments.
-    /*!
-     * Evaluates the stiffness operator (i,j) of the current finite elemente.
-     * \param i is an unsigned int, current finite element local index
-     * \param j is an unsigned int, current finite element local index
-     * returns a double.
-     */
 
      //! A definition of operator () taking four arguments.
     /*!
@@ -65,14 +107,9 @@ class StiffAnys<Eigen::Matrix<Real,2,2> >{
      * \param ic1 is an unsigned int, the variable respect whom the derivative is take: ic1=0 abscissa, ic1=1 ordinata
      * returns a double.
      */
-//    inline Stiff<Integrator, ORDER, Eigen::Matrix<Real,2,2> > operator() (Eigen::Matrix<Real,2,2> K)
-//    {
-//    	Stiff<Integrator, ORDER, Eigen::Matrix<Real,2,2> > anys(K);
-//    	return anys;
-//    }
 
     template<class Integrator, UInt ORDER>
-	inline Real operator() (FiniteElement<Integrator, ORDER>& currentfe_, UInt i, UInt j, UInt iq, UInt ic = 0)
+	inline Real operator() (FiniteElement<Integrator, ORDER,2,2>& currentfe_, UInt i, UInt j, UInt iq, UInt ic = 0)
 	{
 	   	Real s = 0;
 	   	for (UInt icoor=0; icoor < 2; icoor ++)
@@ -85,33 +122,25 @@ class StiffAnys<Eigen::Matrix<Real,2,2> >{
 	   	}
 	   	return s;
 	}
+	
+    template<class Integrator, UInt ORDER>
+	inline Real operator() (FiniteElement<Integrator, ORDER,2,3>& currentfe_, UInt i, UInt j, UInt iq, UInt ic = 0){return 0;}
+	
+template<class Integrator, UInt ORDER>
+	inline Real operator() (FiniteElement<Integrator, ORDER,3,3>& currentfe_, UInt i, UInt j, UInt iq, UInt ic = 0){return 0;}
+	
 };
 
 template <>
 class StiffAnys<Diffusivity>{
   private:
-    //! A reference to FiniteElement<Integrator>
-    /*!
-     * Stores a reference to the finite element where the stiffness operator is evaluated.
-     */
-    //FiniteElement<Integrator, ORDER>& currentfe_;
+
 	const Diffusivity& K_;
   public:
 	//! A constructor.
-	/*!
-	 \param fe is a reference to FiniteElement<Integrator>
-	 */
-    //Stiff(FiniteElement<Integrator, ORDER>& fe):currentfe_(fe),K_(MatrixXr::Identity(2,2)){};
-	//StiffAnys():K_(){};
-    //Stiff(Stiff<Integrator, ORDER>& stiff, Eigen::Matrix<Real,2,2> K): currentfe_(stiff.currentfe_) , K_(K){};
+
 	StiffAnys(const Diffusivity& K): K_(K){};
-    //! A definition of operator () taking two arguments.
-    /*!
-     * Evaluates the stiffness operator (i,j) of the current finite elemente.
-     * \param i is an unsigned int, current finite element local index
-     * \param j is an unsigned int, current finite element local index
-     * returns a double.
-     */
+
 
      //! A definition of operator () taking four arguments.
     /*!
@@ -123,18 +152,9 @@ class StiffAnys<Diffusivity>{
      * \param ic1 is an unsigned int, the variable respect whom the derivative is take: ic1=0 abscissa, ic1=1 ordinata
      * returns a double.
      */
-//    void setAnisotropy(Eigen::Matrix<Real,2,2> K)
-//    {
-//    	K_ = K;
-//    }
 
-//    inline Stiff<Integrator, ORDER, Diffusivity> operator() (const Diffusivity& K)
-//    {
-//    	Stiff<Integrator, ORDER, Diffusivity> anys(K);
-//    	return anys;
-//    }
     template <class Integrator, UInt ORDER>
-	inline Real operator() (FiniteElement<Integrator, ORDER>& currentfe_, UInt i, UInt j, UInt iq, UInt ic = 0)
+	inline Real operator() (FiniteElement<Integrator, ORDER,2,2>& currentfe_, UInt i, UInt j, UInt iq, UInt ic = 0)
 	{
 	   	Real s = 0;
 	   	for (UInt icoor=0; icoor < 2; icoor ++)
@@ -147,51 +167,73 @@ class StiffAnys<Diffusivity>{
 	   	}
 	   	return s;
 	}
+	
+    template <class Integrator, UInt ORDER>
+	inline Real operator() (FiniteElement<Integrator, ORDER,2,3>& currentfe_, UInt i, UInt j, UInt iq, UInt ic = 0){return 0;}
+	
+    template <class Integrator, UInt ORDER>
+	inline Real operator() (FiniteElement<Integrator, ORDER,3,3>& currentfe_, UInt i, UInt j, UInt iq, UInt ic = 0){return 0;}
+	
 };
 
 //! A Mass class: a class for the mass operator.
 class Mass{
 	private:
-    //! A reference to FiniteElement<Integrator>
-    /*!
-     * Stores a reference to the finite element where the mass operator is evaluated.
-     */
-	//FiniteElement<Integrator, ORDER>& currentfe_;
+
 	public:
-	//! A constructor.
-	/*!
-	 \param fe is a reference to FiniteElement<Integrator>
-	 */
-	//Mass(FiniteElement<Integrator, ORDER> & fe ):currentfe_(fe){};
-    //! A definition of operator () taking two arguments.
+	
+    //! A definition of operator () taking three arguments.
     /*!
-     * Evaluates the mass operator (i,j) of the current finite elemente.
+     * Evaluates the mass operator (i,j) of the current finite element.
+     * \param currentfe_ is an object of class FiniteElement<Integrator, ORDER,2,2>, current planar finite element
      * \param i is an unsigned int, current finite element local index
      * \param j is an unsigned int, current finite element local index
      * returns a double.
      */
 	template <class Integrator ,UInt ORDER>
-    inline Real operator() (FiniteElement<Integrator, ORDER>& currentfe_, UInt i, UInt j, UInt iq, UInt ic = 0)
+    inline Real operator() (FiniteElement<Integrator, ORDER,2,2>& currentfe_, UInt i, UInt j, UInt iq, UInt ic = 0)
     {
     	return currentfe_.phiMaster(i,iq)*  currentfe_.phiMaster(j,iq);
-    }
+    };
+    
+    //! A definition of operator () taking three arguments.
+    /*!
+     * Evaluates the mass operator (i,j) of the current finite element.
+     * \param currentfe_ is an object of class FiniteElement<Integrator, ORDER,2,3>, current planar finite element
+     * \param i is an unsigned int, current finite element local index
+     * \param j is an unsigned int, current finite element local index
+     * returns a double.
+     */
+
+	template <class Integrator ,UInt ORDER>
+    inline Real operator() (FiniteElement<Integrator, ORDER,2,3>& currentfe_, UInt i, UInt j, UInt iq, UInt ic = 0)
+    {
+    	return currentfe_.phiMaster(i,iq)*  currentfe_.phiMaster(j,iq);
+    };
+    
+    
+    //! A definition of operator () taking three arguments.
+    /*!
+     * Evaluates the mass operator (i,j) of the current finite element.
+     * \param currentfe_ is an object of class FiniteElement<Integrator, ORDER,3,3>, current planar finite element
+     * \param i is an unsigned int, current finite element local index
+     * \param j is an unsigned int, current finite element local index
+     * returns a double.
+     */
+    template <class Integrator ,UInt ORDER>
+    inline Real operator() (FiniteElement<Integrator, ORDER,3,3>& currentfe_, UInt i, UInt j, UInt iq, UInt ic = 0)
+    {
+    	return currentfe_.phiMaster(i,iq)*  currentfe_.phiMaster(j,iq);
+    };
+
 };
 
 //! A vGrad class: a class for the the vectorial Gradient operator.
 
 class Grad{
 	private:
-    //! A reference to FiniteElement<Integrator>
-    /*!
-     * Stores a reference to the finite element where the stiffness operator is evaluated.
-     */
-	  //FiniteElement<Integrator, ORDER>& currentfe_;
+	
 	public:
-	//! A constructor.
-	/*!
-	 \param fe is a reference to FiniteElement<Integrator>
-	 */
-	//Grad(FiniteElement<Integrator, ORDER> & fe ):currentfe_(fe){};
     //! A definition of operator () taking three arguments.
     /*!
      * Evaluates the component ic of the vGrad operator (i,j) on the current finite elemente.
@@ -201,10 +243,22 @@ class Grad{
      * returns a double.
      */
 	 template<class Integrator, UInt ORDER>
-     inline Real operator() (FiniteElement<Integrator, ORDER>& currentfe_, UInt i, UInt j, UInt iq, UInt ic = 0)
+     inline Real operator() (FiniteElement<Integrator,ORDER,2,2>& currentfe_, UInt i, UInt j, UInt iq, UInt ic = 0)
      {
     	 return currentfe_.phiMaster(i,iq)*currentfe_.invTrJPhiDerMaster(j,ic,iq);
      }
+     
+     
+     // AGGIUNGERE NUOVI METODI PER MESH SUPERFICIALI:
+     //E' UNA SORTA DI DUMMY. DA IMPLEMENTARE SERIAMENTE PER ndim=3
+     
+     	 template<class Integrator, UInt ORDER>
+     inline Real operator() (FiniteElement<Integrator, ORDER,2,3>& currentfe_, UInt i, UInt j, UInt iq, UInt ic = 0){return 0;};
+     
+     template<class Integrator, UInt ORDER>
+     inline Real operator() (FiniteElement<Integrator, ORDER,3,3>& currentfe_, UInt i, UInt j, UInt iq, UInt ic = 0){return 0;};
+     
+     
 };
 
 
@@ -245,7 +299,7 @@ class EOExpr{
      * \param ic is an unsigned int
      * returns a P variable.
      */
-	  EOExpr<StiffAnys<Eigen::Matrix<Real,2,2> > >  operator[] (const Eigen::Matrix<Real,2,2>& K)
+	  EOExpr<StiffAnys<Eigen::Matrix<Real,2,2>> >  operator[] (const Eigen::Matrix<Real,2,2>& K)
       {
 		  typedef EOExpr<StiffAnys<Eigen::Matrix<Real,2,2> > > ExprT;
 		  StiffAnys<Eigen::Matrix<Real,2,2> > anys(K);
@@ -261,11 +315,12 @@ class EOExpr{
 		  //return EOExpr<P,A>(A(K));
 	  }
 
-	  template<typename Integrator, UInt ORDER>
-      Real operator() (FiniteElement<Integrator, ORDER>& currentfe_, UInt i, UInt j, UInt iq, UInt ic = 0)
+	  template<typename Integrator, UInt ORDER,UInt mydim, UInt ndim>
+      Real operator() (FiniteElement<Integrator, ORDER,mydim,ndim>& currentfe_, UInt i, UInt j, UInt iq, UInt ic = 0)
       {
           return a_(currentfe_, i,j,iq,ic);
       }
+      
 	 //! A definition of operator () which takes four arguments.
      /*!
      * Masks the behaviour of the correspondent operator in the above classes.
@@ -311,8 +366,8 @@ class EOBinOp{
      * applies the generic operation defined by the type Op to the two generic objects a_, b_;
      * returns a type P variable
 	 */
-		template<typename Integrator, UInt ORDER>
-	  Real operator () (FiniteElement<Integrator, ORDER>& currentfe_, UInt i, UInt j, UInt iq, UInt ic = 0)
+		template<typename Integrator, UInt ORDER,UInt mydim,UInt ndim>
+	  Real operator () (FiniteElement<Integrator, ORDER,mydim,ndim>& currentfe_, UInt i, UInt j, UInt iq, UInt ic = 0)
 	  {
 		  return Op::apply(a_(currentfe_,i,j, iq, ic),b_(currentfe_, i,j, iq, ic));
 	  }
@@ -326,8 +381,8 @@ class EOBinOp<Real, B, Op>
 public:
 	EOBinOp(Real a, const B& b):M_a(a),M_b(b) {};
 
-	template<typename Integrator, UInt ORDER>
-	inline Real operator()(FiniteElement<Integrator, ORDER>& currentfe_, int i, int j, int iq, int ic = 0)
+	template<typename Integrator, UInt ORDER,UInt mydim, UInt ndim>
+	inline Real operator()(FiniteElement<Integrator, ORDER,mydim,ndim>& currentfe_, int i, int j, int iq, int ic = 0)
 	{
 		return Op::apply(M_a,M_b(currentfe_, i, j, iq, ic));
 	}
@@ -341,8 +396,8 @@ class EOBinOp<Function, B, Op>
 public:
 	EOBinOp(const Function& a, const B& b):M_a(a),M_b(b) {};
 
-	template<typename Integrator, UInt ORDER>
-	inline Real operator()(FiniteElement<Integrator, ORDER>& currentfe_, int i, int j, int iq, int ic = 0)
+	template<typename Integrator, UInt ORDER,UInt mydim, UInt ndim>
+	inline Real operator()(FiniteElement<Integrator, ORDER,mydim,ndim>& currentfe_, int i, int j, int iq, int ic = 0)
 	{
 		UInt globalIndex = currentfe_.getGlobalIndex(iq);
 		return Op::apply(M_a(globalIndex),M_b(currentfe_, i, j, iq, ic));
@@ -401,14 +456,23 @@ class EODotProd
 	B b_;
 	public:
 	EODotProd(const A& a, const B& b):a_(a), b_(b) {};
-	template<typename Integrator, UInt ORDER>
-	inline Real operator()(FiniteElement<Integrator, ORDER>& currentfe_, int i, int j, int iq, int ic = 0)
+	template<typename Integrator, UInt ORDER, UInt ndim>
+	inline Real operator()(FiniteElement<Integrator, ORDER,2,ndim>& currentfe_, int i, int j, int iq, int ic = 0)
 	{
 		Real s = 0.;
 		for(ic = 0; ic < 2; ++ic)
 			s += a_(ic) * b_(currentfe_, i, j, iq, ic);
 	return s;
 	}
+	
+	template<typename Integrator, UInt ORDER>
+	inline Real operator()(FiniteElement<Integrator, ORDER,3,3>& currentfe_, int i, int j, int iq, int ic = 0)
+	{
+		Real s = 0.;
+		for(ic = 0; ic < 3; ++ic)
+			s += a_(ic) * b_(currentfe_, i, j, iq, ic);
+	return s;
+	}
 };
 
 //Dot
@@ -419,8 +483,8 @@ class EODotProd<Function, B>
 	B M_b;
 	public:
 	EODotProd(const Function& a, const B& b):M_a(a), M_b(b) {};
-	template<typename Integrator, UInt ORDER>
-	inline Real operator()(FiniteElement<Integrator, ORDER>& currentfe_, int i, int j, int iq, int ic = 0)
+	template<typename Integrator, UInt ORDER, UInt ndim>
+	inline Real operator()(FiniteElement<Integrator, ORDER,2,ndim>& currentfe_, int i, int j, int iq, int ic = 0)
 	{
 		Real s = 0.;
 		UInt globalIndex = currentfe_.getGlobalIndex(iq);
@@ -428,6 +492,17 @@ class EODotProd<Function, B>
 			s += M_a(globalIndex, ic) * M_b(currentfe_, i, j, iq, ic);
 	return s;
 	}
+	
+	template<typename Integrator, UInt ORDER>
+	inline Real operator()(FiniteElement<Integrator, ORDER,3,3>& currentfe_, int i, int j, int iq, int ic = 0)
+	{
+		Real s = 0.;
+		UInt globalIndex = currentfe_.getGlobalIndex(iq);
+		for(ic = 0; ic < 3; ic++)
+			s += M_a(globalIndex, ic) * M_b(currentfe_, i, j, iq, ic);
+	return s;
+	}
+	
 };
 
 //operator +
@@ -473,6 +548,14 @@ dot(const Eigen::Matrix<Real,2,1>& a, const EOExpr<B>&  b){
 	  return EOExpr<ExprT> (ExprT(a,b));
 }
 
+template<typename B>
+EOExpr<EODotProd<Eigen::Matrix<Real,3,1>, EOExpr<B> > >
+dot(const Eigen::Matrix<Real,3,1>& a, const EOExpr<B>&  b){
+
+	  typedef EODotProd<Eigen::Matrix<Real,3,1>, EOExpr<B> > ExprT;
+	  return EOExpr<ExprT> (ExprT(a,b));
+}
+
 template<typename B>
 EOExpr<EODotProd<Function, EOExpr<B> > >
 dot(const Function& a, const EOExpr<B>&  b){
@@ -484,56 +567,53 @@ dot(const Function& a, const EOExpr<B>&  b){
 
 
 //!A Assmbler class: discretize a generic differential operator in a sparse matrix
+//template<UInt mydim, UInt ndim>
 class Assembler{
 	private:
-
-	  //MatrixXr oper_mat_;
-	  //! A Eigen::sparseMatrix<Real>
-	  /*!
-	   * Stores the discretized differential operator.
-	   */
-	  //SpMat    SPoper_mat_;
-
 	public:
 	  //! A constructor
 	  //Assembler (){};
 	  //! A template member taking three arguments: discretize differential operator
 	  /*!
 	   * \param oper is a template expression : the differential operator to be discretized.
-	   * \param mesh is const reference to a MeshHandler<ORDER>: the mesh where we want to discretize the operator.
+	   * \param mesh is const reference to a MeshHandler<ORDER,2,2>: the mesh where we want to discretize the operator.
 	   * \param fe is a const reference to a FiniteElement
 	   * stores the discretization in SPoper_mat_
 	   */
 
-	  //Obsolet
-	  //template<UInt ORDER, typename Integrator, typename P, typename A>
-	  //void operKernel(EOExpr<P, A> oper,const MeshHandler<ORDER>& mesh,
-	  //                   FiniteElement<Integrator, ORDER>& fe );
-
 	  //Return triplets vector
 	  template<UInt ORDER, typename Integrator, typename A>
-	  static void operKernel(EOExpr<A> oper,const MeshHandler<ORDER>& mesh,
-	  	                     FiniteElement<Integrator, ORDER>& fe, SpMat& OpMat);
+	  static void operKernel(EOExpr<A> oper,const MeshHandler<ORDER,2,2>& mesh,
+	  	                     FiniteElement<Integrator, ORDER,2,2>& fe, SpMat& OpMat);
 
 	  template<UInt ORDER, typename Integrator>
-	  static void forcingTerm(const MeshHandler<ORDER>& mesh, FiniteElement<Integrator, ORDER>& fe, const ForcingTerm& u, VectorXr& forcingTerm);
-
-	  //void getOperKernel(UInt i, UInt j){ std::cout<<oper_mat_(i,j)<<std::endl; };
-	  //! A normal member taking two arguments: access to element (i,j)
+	  static void forcingTerm(const MeshHandler<ORDER,2,2>& mesh, FiniteElement<Integrator, ORDER,2,2>& fe, const ForcingTerm& u, VectorXr& forcingTerm);
+	  
+	  //! A template member taking three arguments: discretize differential operator
 	  /*!
-	   *\param i is an unsigned int
-       *\param j is an unsigned int
-       * print the (i,j) element of SPoper_mat_
+	   * \param oper is a template expression : the differential operator to be discretized.
+	   * \param mesh is const reference to a MeshHandler<ORDER,2,3>: the mesh where we want to discretize the operator.
+	   * \param fe is a const reference to a FiniteElement
+	   * stores the discretization in SPoper_mat_
 	   */
-	  //void getSpOperKernel(UInt i, UInt j){ std::cout<<SPoper_mat_.coeffRef(i,j)<<std::endl; };
-	  //! A normal member returning a reference to the discretized differential operator
-	  /*!
-	   * \return a reference to SP_opermat_
-	   */
-	  //SpMat& getSpOperKernel(){ return (SPoper_mat_); }
-	};
+	  
+	  template<UInt ORDER, typename Integrator, typename A>
+	  static void operKernel(EOExpr<A> oper,const MeshHandler<ORDER,2,3>& mesh,
+	  	                     FiniteElement<Integrator, ORDER,2,3>& fe, SpMat& OpMat);
+
+	  template<UInt ORDER, typename Integrator>
+	  static void forcingTerm(const MeshHandler<ORDER,2,3>& mesh, FiniteElement<Integrator, ORDER,2,3>& fe, const ForcingTerm& u, VectorXr& forcingTerm);
+	  
+	  
+	  template<UInt ORDER, typename Integrator, typename A>
+	  static void operKernel(EOExpr<A> oper,const MeshHandler<ORDER,3,3>& mesh,
+	  	                     FiniteElement<Integrator, ORDER,3,3>& fe, SpMat& OpMat);
+
+	  template<UInt ORDER, typename Integrator>
+	  static void forcingTerm(const MeshHandler<ORDER,3,3>& mesh, FiniteElement<Integrator, ORDER,3,3>& fe, const ForcingTerm& u, VectorXr& forcingTerm);
 
 
+};
 
 
 #include "matrix_assembler_imp.h"
